struct ViolationWording {
detail: &'static str,
reject_log: &'static str,
warn_log: &'static str,
}Expand description
The wording that differs between a violation found in what the producer
put on the bus and one found in what xml_baseline conversion produced.
Fields
detail: &'static strNoun phrase completing “delivery on {sid} …: {summary}”.
reject_log: &'static strwarn_log: &'static strImplementations
Sourceimpl ViolationWording
impl ViolationWording
const PRODUCER: Self
const CONVERSION: Self